@@ -80,9 +80,13 @@
         <translation type="obsolete">cuteTube-QML - 0.8.3 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.9.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.9.0 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.9.0 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.9.4</source>
+        <translation type="unfinished">cuteTube-QML - 0.9.4 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -623,47 +627,47 @@
 <context>
     <name>PlaylistDialog</name>
     <message>
-        <location filename="../PlaylistDialog.qml" line="114"/>
+        <location filename="../PlaylistDialog.qml" line="80"/>
         <source>Playlist Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="159"/>
+        <location filename="../PlaylistDialog.qml" line="125"/>
         <source>Title</source>
         <translation type="unfinished">Titel</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="165"/>
+        <location filename="../PlaylistDialog.qml" line="131"/>
         <source>Videos</source>
         <translation type="unfinished">Videos</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="185"/>
+        <location filename="../PlaylistDialog.qml" line="151"/>
         <source>Created</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="191"/>
+        <location filename="../PlaylistDialog.qml" line="157"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="219"/>
+        <location filename="../PlaylistDialog.qml" line="185"/>
         <source>Description</source>
         <translation type="unfinished">Beschreibung</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="237"/>
+        <location filename="../PlaylistDialog.qml" line="203"/>
         <source>No description</source>
         <translation type="unfinished">Keine Beschreibung</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="252"/>
+        <location filename="../PlaylistDialog.qml" line="218"/>
         <source>Play</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="276"/>
+        <location filename="../PlaylistDialog.qml" line="241"/>
         <source>Download</source>
         <translation type="unfinished"></translation>
     </message>
@@ -695,32 +699,32 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="89"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="111"/>
+        <location filename="../PlaylistVideosView.qml" line="110"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="169"/>
+        <location filename="../PlaylistVideosView.qml" line="168"/>
         <source>Videos</source>
         <translation type="unfinished">Videos</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="183"/>
+        <location filename="../PlaylistVideosView.qml" line="182"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="206"/>
+        <location filename="../PlaylistVideosView.qml" line="205"/>
         <source>Play all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="214"/>
+        <location filename="../PlaylistVideosView.qml" line="213"/>
         <source>Loading playlist videos. Please wait</source>
         <translation type="unfinished"></translation>
     </message>
@@ -750,17 +754,17 @@
 <context>
     <name>ProxyDialog</name>
     <message>
-        <location filename="../ProxyDialog.qml" line="30"/>
+        <location filename="../ProxyDialog.qml" line="35"/>
         <source>Network Proxy</source>
         <translation type="unfinished">Netzwerk Proxy</translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="44"/>
+        <location filename="../ProxyDialog.qml" line="49"/>
         <source>Host (e.g. 192.168.100.1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="51"/>
+        <location filename="../ProxyDialog.qml" line="56"/>
         <source>Port (e.g. 8080)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -784,7 +788,7 @@
         <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="183"/>
+        <location filename="../SearchBar.qml" line="185"/>
         <source>Order by:</source>
         <translation>Sortieren nach:</translation>
     </message>
@@ -1732,10 +1736,67 @@
         <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
     </message>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="165"/>
+        <location filename="../VideoPlaybackView.qml" line="233"/>
+        <location filename="../VideoPlaybackView.qml" line="422"/>
+        <location filename="../VideoPlaybackView.qml" line="1024"/>
         <source>Loading...</source>
         <translation type="unfinished">Lade...</translation>
     </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="731"/>
+        <source>Info</source>
+        <translation type="unfinished">Info</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="769"/>
+        <source>Comments</source>
+        <translation type="unfinished">Kommentare</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="807"/>
+        <source>Playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>By </source>
+        <translation type="unfinished">Von </translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source> on </source>
+        <translation type="unfinished"> am </translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>Added on </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="954"/>
+        <source>Views</source>
+        <translation type="unfinished">Aufrufe</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="968"/>
+        <source>Description</source>
+        <translation type="unfinished">Beschreibung</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="976"/>
+        <source>No description</source>
+        <translation type="unfinished">Keine Beschreibung</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source>No comments</source>
+        <translation type="unfinished">Keine Kommentare</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source> comments</source>
+        <translation type="unfinished">Kommentare</translation>
+    </message>
 </context>
 <context>
     <name>Widget</name>
