@@ -60,9 +60,13 @@
         <translation type="obsolete">cuteTube-QML - 0.8.3 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.9.0</source>
-        <translation type="unfinished">cuteTube-QML - 0.9.0 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.9.0 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.9.4</source>
+        <translation type="unfinished">cuteTube-QML - 0.9.4 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -563,47 +567,47 @@
 <context>
     <name>PlaylistDialog</name>
     <message>
-        <location filename="../PlaylistDialog.qml" line="114"/>
+        <location filename="../PlaylistDialog.qml" line="80"/>
         <source>Playlist Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="159"/>
+        <location filename="../PlaylistDialog.qml" line="125"/>
         <source>Title</source>
         <translation type="unfinished">Otsikko</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="165"/>
+        <location filename="../PlaylistDialog.qml" line="131"/>
         <source>Videos</source>
         <translation type="unfinished">Videot</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="185"/>
+        <location filename="../PlaylistDialog.qml" line="151"/>
         <source>Created</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="191"/>
+        <location filename="../PlaylistDialog.qml" line="157"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="219"/>
+        <location filename="../PlaylistDialog.qml" line="185"/>
         <source>Description</source>
         <translation type="unfinished">Kuvaus</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="237"/>
+        <location filename="../PlaylistDialog.qml" line="203"/>
         <source>No description</source>
         <translation type="unfinished">Ei kuvausta</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="252"/>
+        <location filename="../PlaylistDialog.qml" line="218"/>
         <source>Play</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="276"/>
+        <location filename="../PlaylistDialog.qml" line="241"/>
         <source>Download</source>
         <translation type="unfinished"></translation>
     </message>
@@ -635,32 +639,32 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="89"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="111"/>
+        <location filename="../PlaylistVideosView.qml" line="110"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="169"/>
+        <location filename="../PlaylistVideosView.qml" line="168"/>
         <source>Videos</source>
         <translation type="unfinished">Videot</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="183"/>
+        <location filename="../PlaylistVideosView.qml" line="182"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="206"/>
+        <location filename="../PlaylistVideosView.qml" line="205"/>
         <source>Play all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="214"/>
+        <location filename="../PlaylistVideosView.qml" line="213"/>
         <source>Loading playlist videos. Please wait</source>
         <translation type="unfinished"></translation>
     </message>
@@ -690,17 +694,17 @@
 <context>
     <name>ProxyDialog</name>
     <message>
-        <location filename="../ProxyDialog.qml" line="30"/>
+        <location filename="../ProxyDialog.qml" line="35"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="44"/>
+        <location filename="../ProxyDialog.qml" line="49"/>
         <source>Host (e.g. 192.168.100.1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="51"/>
+        <location filename="../ProxyDialog.qml" line="56"/>
         <source>Port (e.g. 8080)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -724,7 +728,7 @@
         <translation type="obsolete">Katseluja</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="183"/>
+        <location filename="../SearchBar.qml" line="185"/>
         <source>Order by:</source>
         <translation>Järjestä: </translation>
     </message>
@@ -1664,10 +1668,67 @@
         <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="165"/>
+        <location filename="../VideoPlaybackView.qml" line="233"/>
+        <location filename="../VideoPlaybackView.qml" line="422"/>
+        <location filename="../VideoPlaybackView.qml" line="1024"/>
         <source>Loading...</source>
         <translation type="unfinished">Ladataan...</translation>
     </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="731"/>
+        <source>Info</source>
+        <translation type="unfinished">Tietoa</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="769"/>
+        <source>Comments</source>
+        <translation type="unfinished">Kommentit</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="807"/>
+        <source>Playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>By </source>
+        <translation type="unfinished">Kirjoittaja: </translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source> on </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>Added on </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="954"/>
+        <source>Views</source>
+        <translation type="unfinished">Katseluja</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="968"/>
+        <source>Description</source>
+        <translation type="unfinished">Kuvaus</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="976"/>
+        <source>No description</source>
+        <translation type="unfinished">Ei kuvausta</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source>No comments</source>
+        <translation type="unfinished">Ei kommentteja</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source> comments</source>
+        <translation type="unfinished">kommentit</translation>
+    </message>
 </context>
 <context>
     <name>Widget</name>
