@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.9.0</source>
+        <source>cuteTube-QML - 0.9.4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -413,47 +413,47 @@
 <context>
     <name>PlaylistDialog</name>
     <message>
-        <location filename="../PlaylistDialog.qml" line="114"/>
+        <location filename="../PlaylistDialog.qml" line="80"/>
         <source>Playlist Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="159"/>
+        <location filename="../PlaylistDialog.qml" line="125"/>
         <source>Title</source>
         <translation type="unfinished">Título</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="165"/>
+        <location filename="../PlaylistDialog.qml" line="131"/>
         <source>Videos</source>
         <translation type="unfinished">Vídeos</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="185"/>
+        <location filename="../PlaylistDialog.qml" line="151"/>
         <source>Created</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="191"/>
+        <location filename="../PlaylistDialog.qml" line="157"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="219"/>
+        <location filename="../PlaylistDialog.qml" line="185"/>
         <source>Description</source>
         <translation type="unfinished">Descrição</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="237"/>
+        <location filename="../PlaylistDialog.qml" line="203"/>
         <source>No description</source>
         <translation type="unfinished">Sem descrição</translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="252"/>
+        <location filename="../PlaylistDialog.qml" line="218"/>
         <source>Play</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistDialog.qml" line="276"/>
+        <location filename="../PlaylistDialog.qml" line="241"/>
         <source>Download</source>
         <translation type="unfinished"></translation>
     </message>
@@ -461,32 +461,32 @@
 <context>
     <name>PlaylistVideosView</name>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="90"/>
+        <location filename="../PlaylistVideosView.qml" line="89"/>
         <source>Video(s) deleted from playlist</source>
         <translation>Vídeo(s) excluído(s) da lista</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="111"/>
+        <location filename="../PlaylistVideosView.qml" line="110"/>
         <source>No videos found</source>
         <translation>Não foram encontrados vídeos</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="169"/>
+        <location filename="../PlaylistVideosView.qml" line="168"/>
         <source>Videos</source>
         <translation type="unfinished">Vídeos</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="183"/>
+        <location filename="../PlaylistVideosView.qml" line="182"/>
         <source>Updated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="206"/>
+        <location filename="../PlaylistVideosView.qml" line="205"/>
         <source>Play all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="214"/>
+        <location filename="../PlaylistVideosView.qml" line="213"/>
         <source>Loading playlist videos. Please wait</source>
         <translation type="unfinished"></translation>
     </message>
@@ -512,17 +512,17 @@
 <context>
     <name>ProxyDialog</name>
     <message>
-        <location filename="../ProxyDialog.qml" line="30"/>
+        <location filename="../ProxyDialog.qml" line="35"/>
         <source>Network Proxy</source>
         <translation>Proxy da Rede</translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="44"/>
+        <location filename="../ProxyDialog.qml" line="49"/>
         <source>Host (e.g. 192.168.100.1)</source>
         <translation>Anfitrião (ex: 192.168.100.1)</translation>
     </message>
     <message>
-        <location filename="../ProxyDialog.qml" line="51"/>
+        <location filename="../ProxyDialog.qml" line="56"/>
         <source>Port (e.g. 8080)</source>
         <translation>Porta (ex: 8080)</translation>
     </message>
@@ -546,7 +546,7 @@
         <translation type="obsolete">Vistas</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="183"/>
+        <location filename="../SearchBar.qml" line="185"/>
         <source>Order by:</source>
         <translation>Ordenar por:</translation>
     </message>
@@ -1398,10 +1398,67 @@
 <context>
     <name>VideoPlaybackView</name>
     <message>
-        <location filename="../VideoPlaybackView.qml" line="165"/>
+        <location filename="../VideoPlaybackView.qml" line="233"/>
+        <location filename="../VideoPlaybackView.qml" line="422"/>
+        <location filename="../VideoPlaybackView.qml" line="1024"/>
         <source>Loading...</source>
         <translation type="unfinished">A Carregar...</translation>
     </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="731"/>
+        <source>Info</source>
+        <translation type="unfinished">Info</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="769"/>
+        <source>Comments</source>
+        <translation type="unfinished">Comentários</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="807"/>
+        <source>Playlist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>By </source>
+        <translation type="unfinished">Por </translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source> on </source>
+        <translation type="unfinished"> em </translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="889"/>
+        <source>Added on </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="954"/>
+        <source>Views</source>
+        <translation type="unfinished">Vistas</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="968"/>
+        <source>Description</source>
+        <translation type="unfinished">Descrição</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="976"/>
+        <source>No description</source>
+        <translation type="unfinished">Sem descrição</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source>No comments</source>
+        <translation type="unfinished">Sem comentários</translation>
+    </message>
+    <message>
+        <location filename="../VideoPlaybackView.qml" line="1001"/>
+        <source> comments</source>
+        <translation type="unfinished"> comentários</translation>
+    </message>
 </context>
 <context>
     <name>YouTube</name>
