@@ -248,7 +248,7 @@ function loadPlaybackView(videoList) {
         var loader = viewsModel.children[windowView.currentIndex + 1];
         windowView.currentItem.opacity = 0;
         loader.source = "VideoPlaybackView.qml";
-        notificationArea.addTitle(qsTr("Video Playback"));
+        notificationArea.addTitle(qsTr("Playback View"));
         loader.item.setPlaylist(videoList);
         toggleControls(false);
         _VIDEO_PLAYING = true;
