@@ -80,10 +80,10 @@ void YouTube::uploadVideo(const QString &filename, const QString &title, const Q
                    "xmlns:media=\"http://search.yahoo.com/mrss/\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
                    "<media:group>\n" \
-                   "<media:title>" + title.toAscii().toPercentEncoding() + "</media:title>\n" \
-                   "<media:description>\n" + description.toAscii().toPercentEncoding() + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
+                   "<media:title>" + title.toAscii().toPercentEncoding(" ") + "</media:title>\n" \
+                   "<media:description>\n" + description.toAscii().toPercentEncoding(" ") + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
                    "<media:category scheme=\"http://gdata.youtube.com/schemas/2007/categories.cat\">\n" + category.toAscii() + "\n</media:category>\n" \
-                   "<media:keywords>" + tags.toAscii().toPercentEncoding() + "</media:keywords>\n" \
+                   "<media:keywords>" + tags.toAscii().toPercentEncoding(" ") + "</media:keywords>\n" \
                    "</media:group>\n" \
                    "</entry>");
 
@@ -285,8 +285,8 @@ void YouTube::createNewPlaylist(const QString &title, const QString &description
     QByteArray xml("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" \
                    "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
-                   "<title>" + title.toAscii().toPercentEncoding() + "</title>\n" \
-                   "<summary>" + description.toAscii().toPercentEncoding() + "</summary>\n" \
+                   "<title>" + title.toAscii().toPercentEncoding(" ") + "</title>\n" \
+                   "<summary>" + description.toAscii().toPercentEncoding(" ") + "</summary>\n" \
                    "</entry>");
     if (isPrivate) {
         int index = xml.lastIndexOf("<");
@@ -338,7 +338,7 @@ void YouTube::addComment(const QString &videoId, const QString &comment) {
     QByteArray xml("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n" \
                    "<entry xmlns=\"http://www.w3.org/2005/Atom\"\n" \
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
-                   "<content>" + comment.toAscii().toPercentEncoding() + "</content>\n" \
+                   "<content>" + comment.toAscii().toPercentEncoding(" ") + "</content>\n" \
                    "</entry>");
     postRequest(url, xml);
     connect(this, SIGNAL(postSuccessful()), this, SIGNAL(commentAdded()));
@@ -352,7 +352,7 @@ void YouTube::replyToComment(const QString &videoId, const QString &commentId, c
                    "<link rel=\"http://gdata.youtube.com/schemas/2007#in-reply-to\"\n" \
                    "type=\"application/atom+xml\"\n" \
                    "href=\"http://gdata.youtube.com/feeds/api/videos/" + videoId.toAscii() + "/comments/" + commentId.toAscii() + "\"/>\n" \
-                   "<content>" + comment.toAscii().toPercentEncoding() + "</content>\n" \
+                   "<content>" + comment.toAscii().toPercentEncoding(" ") + "</content>\n" \
                    "</entry>");
     postRequest(url, xml);
 }
